#ifndef MYX_QT_POSIX_SIGNAL_WATCHER_HPP_
#define MYX_QT_POSIX_SIGNAL_WATCHER_HPP_

#pragma once

#include <myx/core/config.hpp>

#include <QObject>

#include <csignal>

namespace myx {

namespace qt {

class PosixSignalWatcherPrivate;

#if defined( Q_OS_WIN )
const int SIGINT  = 2;
const int SIGTERM = 15;
#endif


/*!
 * \brief The PosixSignalWatcher class converts Posix signals to Qt signals.
 *
 * To watch for a given signal, e.g. \c SIGINT, call \c watchForSignal(SIGINT)
 * and \c connect() your handler to posixSignal().
 */
class PosixSignalWatcher : public QObject
{
	Q_OBJECT

public:
	explicit PosixSignalWatcher( QObject* parent = nullptr );

	void watchForSignal( int signal );
	Q_SIGNAL void posixSignal( int signal );

private:
	PosixSignalWatcherPrivate* const d_ptr = nullptr;
	Q_DECLARE_PRIVATE( PosixSignalWatcher ) //NOLINT
}; // class PosixSignalWatcher

} // namespace qt

} // namespace myx

#endif // ifndef MYX_QT_POSIX_SIGNAL_WATCHER_HPP_
